==> nextcloud-13.0.1.tgz: nextcloud/apps/survey_client/l10n/tr.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Kullanım anketi",
    "Sent on: {on}" : "Gönderilme: {on}",
    "An error occurred while sending your report." : "Raporunuz gönderilirken bir sorun çıktı.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Uygulama listesi <em>(her uygulama için, ad, sürüm, etkinlik durumu)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Veritabanı ortamı <em>(tür, sürüm, veritabanı boyutu)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Şifreleme bilgileri <em>(etkin?, varsayılan modül hangisi)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Paylaşım sayısı <em>(türlere göre izin ayarları)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP ortamı <em>(sürüm, bellek sınırı, en uzun yürütme süresi, en büyük dosya boyutu)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Sunucu kopyası bilgileri <em>(sürüm, kullanılan memcache, kilitleme/önizleme/avatarlar durumu)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "İstatistikler <em>(dosya sayısı, kullanıcılar, tüm depolama türleri, yorum ve etiketler)</em>",
    "Help improve Nextcloud" : "Nextcloud gelişimini destekleyin",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Adsız bilgiler sağlayarak gelecek Nextcloud sürümlerini geliştirmemize yardımcı olmak ister misiniz? Bu özelliği isteğiniz zaman yönetici ayarları bölümünden devre dışı bırakarak bilgilerin gönderilmesini engelleyebilirsiniz.",
    "Not now" : "Şimdi değil",
    "Send usage" : "Kullanım bilgilerini gönder",
    "Never" : "Asla",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Geçerli kurulum ve kullanımınız hakkında bilgiler sağlayarak gelecek Nextcloud sürümlerini geliştirmemize yardımcı olabilirsiniz.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Kişisel gizliliğinizin korunmasına özen gösteriyoruz. Verilerin paylaşılması varsayılan olarak devre dışı bırakılmıştır ve ancak siz etkinleştirirseniz paylaşılır. Öncelikle veriler adsız olarak paylaşılır, ardından paylamak istediğiniz verileri seçebilirsiniz. Yeni bir veri gönderildiğinde bir önce gönderilmiş verilerin tümü silinir.  Sunucu üzerindeki verilerin silinmesini istiyorsanız boş bir rapor yükleyebilirsiniz.",
    "Send new report now" : "Bilgileri şimdi gönder",
    "Send usage survey monthly" : "Kullanım bilgileri aylık olarak gönderilsin",
    "Data to send" : "Gönderilecek veriler",
    "Last report" : "Son rapor",
    "Sent on: %s" : "Gönderim zamanı: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Uygulama listesi <em>(her uygulama için, ad, sürüm, etkin?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Sunucu kopyası bilgileri <em>(sürüm, kullanılan memcache, kilitleme/önizleme/avatarlar etkin mi?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Adsız bilgiler sağlayarak gelecek Nextcloud sürümlerini geliştirmemize yardımcı olabilirsiniz.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Gizliliğinize önem veriyoruz. Verilerde herhangi bir kişisel bilgi bulunmaz ve adsız olarak gönderilir. Bilgi gönderimini istediğiniz zaman durdurabilirsiniz. Ayrıca aşağıdan istediğiniz zaman bize gönderilen son rapordaki bilgileri görüp ayarlayabilirsiniz. Sunucu kullandığınız kopyadan yeni bir rapor aldığında, önceki rapordaki tüm bilgiler silinir. Aşağıdaki ayarlardan birini devre dışı bırakırsanız yeni bir rapor gönderebilirsiniz, böylece sunucuda bulunan önceki veriler silinir."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/survey_client/l10n/tr.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Son rapor gönderimi: {on}",
    "An error occurred while sending your report." : "Raporunuz gönderilirken bir sorun çıktı.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Uygulama listesi <em>(her uygulama için, ad, sürüm, etkinlik durumu)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Veritabanı ortamı <em>(tür, sürüm, veritabanı boyutu)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Şifreleme bilgileri <em>(etkin?, varsayılan modül hangisi)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Paylaşım sayısı <em>(türlere göre izin ayarları)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP ortamı <em>(sürüm, bellek sınırı, en uzun yürütme süresi, en büyük dosya boyutu)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Sunucu kopyası bilgileri <em>(sürüm, kullanılan memcache, kilitleme/ön izlemeler/avatarlar durumu)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "İstatistikler <em>(dosya, kullanıcı, her türdeki depolama, yorum ve etiket sayıları)</em>",
    "Usage survey" : "Kullanım anketi",
    "Help improve Nextcloud" : "Nextcloud gelişimini destekleyin",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Adsız bilgiler sağlayarak gelecek Nextcloud sürümlerini geliştirmemize yardımcı olmak ister misiniz? Bu özelliği isteğiniz zaman yönetici ayarları bölümünden devre dışı bırakarak bilgilerin gönderilmesini engelleyebilirsiniz.",
    "Not now" : "Şimdi değil",
    "Send usage" : "Kullanım bilgilerini gönder",
    "Never" : "Asla",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Nextcloud uygulamasını geliştirmemiz için bize anonimleştirilmiş veriler yollar.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Nextcloud uygulamasını geliştirmemiz için bize anonimleştirilmiş veriler yollar.\nGönderilen içeriğin ne olduğunu istediğiniz zaman görüp değiştirebilir ya da \nanonim verilerin gönderilmesini engelleyebilirsiniz.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Geçerli kurulum ve kullanımınız hakkında bilgiler sağlayarak gelecek Nextcloud sürümlerini geliştirmemize yardımcı olabilirsiniz.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Kişisel gizliliğinizin korunmasına özen gösteriyoruz. Verilerin paylaşılması varsayılan olarak devre dışı bırakılmıştır ve ancak siz etkinleştirirseniz paylaşılır. Öncelikle veriler adsız olarak paylaşılır, ardından paylamak istediğiniz verileri seçebilirsiniz. Yeni bir veri gönderildiğinde bir önce gönderilmiş verilerin tümü silinir.  Sunucu üzerindeki verilerin silinmesini istiyorsanız boş bir rapor yükleyebilirsiniz.",
    "Send new report now" : "Bilgileri şimdi gönder",
    "Send usage survey monthly" : "Kullanım bilgileri aylık olarak gönderilsin",
    "Data to send" : "Gönderilecek veriler",
    "Last report sent on: %s" : "Son rapor gönderimi: %s",
    "Last report" : "Son rapor"
},
"nplurals=2; plural=(n > 1);");
